==> igniteui-webcomponents-core-1.4.2.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionChangedEventArgsDescription, _super);
    function PropertyEditorPropertyDescriptionChangedEventArgsDescription() {
        return _super.call(this) || this;
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescription.prototype.get_type = function () {
        return "PropertyEditorPropertyDescriptionChangedEventArgs";
    };
    Object.defineProperty(PropertyEditorPropertyDescriptionChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    PropertyEditorPropertyDescriptionChangedEventArgsDescription.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescription, 'PropertyEditorPropertyDescriptionChangedEventArgsDescription', Description.$);
    return PropertyEditorPropertyDescriptionChangedEventArgsDescription;
}(Description));
export { PropertyEditorPropertyDescriptionChangedEventArgsDescription };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionChangedEventArgsDescription, _super);
    function PropertyEditorPropertyDescriptionChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescription.prototype.get_type = function () {
        return "PropertyEditorPropertyDescriptionChangedEventArgs";
    };
    Object.defineProperty(PropertyEditorPropertyDescriptionChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PropertyEditorPropertyDescriptionChangedEventArgsDescription.prototype, "newValue", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("NewValue");
        },
        enumerable: true,
        configurable: true
    });
    PropertyEditorPropertyDescriptionChangedEventArgsDescription.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescription, 'PropertyEditorPropertyDescriptionChangedEventArgsDescription', Description.$);
    return PropertyEditorPropertyDescriptionChangedEventArgsDescription;
}(Description));
export { PropertyEditorPropertyDescriptionChangedEventArgsDescription };
